Sets
===========

.. automodule:: sympy.sets.sets

Set
^^^
.. autoclass:: Set
   :members:

.. autofunction:: imageset

Elementary Sets
---------------

Interval
^^^^^^^^
.. autoclass:: Interval
   :members:

FiniteSet
^^^^^^^^^
.. autoclass:: FiniteSet
   :members:

Compound Sets
-------------
Union
^^^^^
.. autoclass:: Union
   :members:

Intersection
^^^^^^^^^^^^
.. autoclass:: Intersection
   :members:

ProductSet
^^^^^^^^^^
.. autoclass:: ProductSet
   :members:

Complement
^^^^^^^^^^
.. autoclass:: Complement
   :members:

Singleton Sets
--------------

EmptySet
^^^^^^^^
.. autoclass:: EmptySet
   :members:

UniversalSet
^^^^^^^^^^^^
.. autoclass:: UniversalSet
   :members:

Special Sets
------------
.. automodule:: sympy.sets.fancysets

Naturals
^^^^^^^^
.. autoclass:: Naturals
   :members:

Naturals0
^^^^^^^^^
.. autoclass:: Naturals0
   :members:

Integers
^^^^^^^^
.. autoclass:: Integers
   :members:

ImageSet
^^^^^^^^
.. autoclass:: ImageSet
   :members:

Range
^^^^^
.. autoclass:: Range
   :members:

ComplexRegion
^^^^^^^^^^^^^
.. autoclass:: ComplexRegion
   :members:

.. autofunction:: normalize_theta_set
